<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.pluginmill.com
 * @since      9.1.0.0
 *
 * @package    Pm_Lead_Filter
 * @subpackage Pm_Lead_Filter/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Pm_Lead_Filter
 * @subpackage Pm_Lead_Filter/public
 * @author     Lynette Chandler <lynette@pluginmill.com>
 */
class Pm_Lead_Filter_Public {

	private $plugin_slug;
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    9.1.0.0
	 * @param      string    $plugin_slug       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_slug, $version ) {
		$options = new Pm_Lead_Filter_Options( array() );
		$this->options = $options->load();
		$this->campaigns = $this->options->load_other('pm_lead_filter_campaigns');
		$this->plugin_slug = $plugin_slug;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    9.1.0.0
	 */
	public function enqueue_styles() {

		/**
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pm_Lead_Filter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pm_Lead_Filter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$display = $this->display_check();

		if( $display['show'] == 1 ) {
			wp_enqueue_style( $this->plugin_slug, plugin_dir_url( __FILE__ ) . 'css/pm-lead-filter-public.css', array(), $this->version, 'all' );
		}
		

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    9.1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Pm_Lead_Filter_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Pm_Lead_Filter_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		$display = $this->display_check();
		$campaigns = $this->campaigns;

		if( $display['show'] == 1 ) {
			$delay = ( empty($campaigns[$display['id']]['popup_delay']) ) ? '' : stripslashes( $campaigns[$display['id']]['popup_delay'] ) ;
			$cookie_duration = ( empty($campaigns[$display['id']]['cookie_duration']) ) ? '' : stripslashes( $campaigns[$display['id']]['cookie_duration'] ) ;
			
			wp_enqueue_script( $this->plugin_slug, plugin_dir_url( __FILE__ ) . 'js/pm-lead-filter-public.js', array( 'jquery' ), $this->version, false );
			wp_localize_script(
				$this->plugin_slug,
				'pm_lead_filter_obj',
				array(
					'nonce' => wp_create_nonce( 'pm_lead_filter_obj' ),
					'delay' => $delay,
					'cookie_duration' => $cookie_duration,
					'ajaxurl' => admin_url( 'admin-ajax.php' ),
					'clientip' => stripslashes($_SERVER['REMOTE_ADDR']),
					)
				);
		}

	}

	public function render_footer() {
		global $post;
		$display_settings = $this->options->get('display_settings');
		$display = $this->display_check();
		$campaigns = $this->campaigns;
		$background = ( $campaigns[$display['id']]['background']['type'] === 'color' ) ? 'style="background-color:'.stripslashes($campaigns[$display['id']]['background']['color']).'"' : 'style="background-image:url(\''.stripslashes($campaigns[$display['id']]['background']['bg_img']).'\')"' ;
		$text_color = ( $campaigns[$display['id']]['text_color'] ) ? 'style="color:'.stripslashes($campaigns[$display['id']]['text_color']).'"' : '' ;

		if( $display['show'] == 1 ) {
		?>
			<div id="pm-lead-filter-frame" class="pm-lead-filter-white-popup mfp-hide" <?php echo $background; ?>>
				<div id="pm-lead-filter-content" <?php echo $text_color; ?>>
					<?php echo $campaigns[$display['id']]['campaign_content'];?>
				</div>
				<div id="pm-lead-filter-cta-opts">
					<?php
					$this->render_filter_button( $display['id'], 'button1' );
					$this->render_filter_button( $display['id'], 'button2' ); ?>
				</div>
					<?php

					$this->render_cta_optin( $display['id'], 'button1' );

					$this->render_cta_optin( $display['id'], 'button2' );
					?>
			</div>
		<?php
		}
	}

	private function display_check() {
		global $post;
		$display_settings = $this->options->get('display_settings');

		if( is_front_page() && $display_settings['enable_home'] == 'on' ) {
			$display['show'] = 1;
			$display['id'] = $display_settings['home_campaign'];
		} else {
			$meta = get_post_meta( $post->ID, 'pm_lead_filter_meta', true );
			if( $meta['enable'] == 'on' ) {
				$display['show'] = 1;
				$display['id'] = $meta['campaignid'];
			}

		}

		return $display;
	}

	private function render_filter_button( $campaignid, $button ) {
		$btn = ( $button === 'button1' ) ? '1' : '2' ;
		$text_color = ( $this->campaigns[$campaignid][$button]['text_color'] ) ? 'color:'.stripslashes($this->campaigns[$campaignid][$button]['text_color']).';' : '';
		$color = ( $this->campaigns[$campaignid][$button]['color'] ) ? 'background-color:'.stripslashes($this->campaigns[$campaignid][$button]['color']).';' : '';
		$label = ( $this->campaigns[$campaignid][$button]['label'] ) ? stripslashes($this->campaigns[$campaignid][$button]['label']) : '';
		?>
		<div id="pm-lead-filter-cont-btn<?php echo $btn; ?>" class="pm-lead-filter-buttons">
			<button id="pm-lead-filter-btn<?php echo $btn; ?>" class="pm-lead-filter-btn" style="<?php echo $text_color.$color; ?>">
				<?php echo $label; ?>
			</button>
		</div>
		<?php
	}

	private function render_cta_optin( $campaignid, $button ) {
		$campaign = $this->campaigns[$campaignid];
		$form = $this->stripslashes_deep($campaign[$button]);
		$btn = ( $button === 'button1' ) ? '1' : '2' ;
		?>
		<div id="pm-lead-filter-cta-cont-btn<?php echo $btn; ?>" class="pm-lead-filter-cta-container" style="color:<?php echo $campaign['text_color']; ?>">
		<div class="pm-lead-filter-cta">
			<?php echo $form['cta']; ?>
		</div>
		<?php
		if( $form['email_service'] === 'html' ) {
			echo $form['list'];
		} else {
			if( $form['noNameField'] != 1 ) {
			?>
			<div class="pm-lead-filter-optin-form">
				<input type="text" class="pm-lead-filter-name" name="pm_lead_filter_name" placeholder="Name">
			<?php } ?>
				<input type="text" class="pm-lead-filter-email" name="pm_lead_filter_email" placeholder="Email">
				<button class="pm-lead-filter-submit" data-emailservice="<?php echo $form['email_service']; ?>" data-listid="<?php echo $form['list']; ?>" data-button="<?php echo $button; ?>" data-campaignid="<?php echo $campaignid; ?>" <?php echo 'style="background-color:'.$form['color'].';color:'.$form['text_color'].';"'; ?>><?php if( $form[$button]['label'] ) { echo $form[$button]['label']; } else { _e('Subscribe', 'pm-lead-filter'); } ?></button>
			</div>
		</div>
			<?php
		}
	}

	private function stripslashes_deep( $value ) {
		$value = is_array($value) ? array_map('stripslashes_deep', $value) : stripslashes($value);
		return $value;
	}

	public function subscribe_lead() {
		if( !wp_verify_nonce( $_POST['nonce'], 'pm_lead_filter_obj' ) )
			return;

		$options = $this->options->get('email_services');
		$options['campaigns'] = $this->campaigns;
		$listid = ( empty($_POST['listid']) ) ? '' : sanitize_text_field( $_POST['listid'] );
		$campaignid = ( empty($_POST['campaignid']) ) ? '' : sanitize_text_field( $_POST['campaignid'] );
		$button = ( empty($_POST['button']) ) ? '' : sanitize_text_field( $_POST['button'] );
		$name = ( empty($_POST['name']) ) ? '' : sanitize_text_field( $_POST['name'] );
		$email = ( empty($_POST['email']) ) ? '' : sanitize_email( $_POST['email'] );
		$clientip = ( empty($_POST['clientip']) ) ? '' : stripslashes( $_POST['clientip'] );

		if( $_POST['email_service'] === 'aw' ) {
			$aweber = new Pmill_Aweber_Api( $options );
			echo $aweber->add_subscriber( $name, $email, $campaignid, $listid, $button, $clientip );
		} elseif ( $_POST['email_service'] === 'mc' ) {
			$mc = new Pmill_Mailchimp_Api( $options );
			echo $mc->add_subscriber( $name, $email, $campaignid, $listid, $button, $clientip );
		} else {
			return;
		}

		die();
	}

	public function run() {
		add_action( 'wp_footer', array($this, 'render_footer') );
		add_action( 'wp_ajax_pm_lead_filter_subscribe', array($this, 'subscribe_lead') );
		add_action( 'wp_ajax_nopriv_pm_lead_filter_subscribe', array($this, 'subscribe_lead') );
	}

}
